pub enum MemoryMonitorRequest {
GetSnapshot {
snapshot: Socket,
control_handle: MemoryMonitorControlHandle,
},
GetSystemStatistics {
responder: MemoryMonitorGetSystemStatisticsResponder,
},
GetAbridgedSnapshot {
snapshot: Socket,
control_handle: MemoryMonitorControlHandle,
},
#[non_exhaustive] _UnknownMethod {
ordinal: u64,
control_handle: MemoryMonitorControlHandle,
method_type: MethodType,
},
}Variants
GetSnapshot
Returns a memory snapshot of the device. Computing this snapshot may be expensive.
GetSystemStatistics
Returns system-level memory statistics for the device. Computing these statistics is less expensive than computing a memory snapshot.
Fields

responder: MemoryMonitorGetSystemStatisticsResponderGetAbridgedSnapshot
Returns a fast memory snapshot of the device that omits Starnix processes.
#[non_exhaustive]_UnknownMethod
An interaction was received which does not match any known method.
Fields
This variant is marked as non-exhaustive
Non-exhaustive enum variants could have additional fields added in future. Therefore, non-exhaustive enum variants cannot be constructed in external crates and cannot be matched against.

control_handle: MemoryMonitorControlHandle
method_type: MethodTypeImplementations
Sourceimpl MemoryMonitorRequest
impl MemoryMonitorRequest
pub fn into_get_snapshot(self) -> Option<(Socket, MemoryMonitorControlHandle)>
pub fn into_get_system_statistics( self, ) -> Option<MemoryMonitorGetSystemStatisticsResponder>
pub fn into_get_abridged_snapshot( self, ) -> Option<(Socket, MemoryMonitorControlHandle)>
Sourcepub fn method_name(&self) -> &'static str
pub fn method_name(&self) -> &'static str
Name of the method defined in FIDL